@@ -10,9 +10,13 @@ class TestTime(TestCase):
         self.assertEqual(libdispatch.USEC_PER_SEC, 1_000_000)
         self.assertEqual(libdispatch.NSEC_PER_USEC, 1000)
 
+        self.assertEqual(libdispatch.DISPATCH_TIME_FOREVER, 18446744073709551615)
+
         self.assertEqual(libdispatch.DISPATCH_TIME_NOW, 0)
         self.assertEqual(libdispatch.DISPATCH_TIME_FOREVER, 0xFFFFFFFFFFFFFFFF)
 
+        self.assertEqual(libdispatch.DISPATCH_WALLTIME_NOW, 0xFFFFFFFFFFFFFFFE)
+
     def test_structs(self):
 
         tv = libdispatch.timespec(50, 100)
